Alexandre Julliard : gdi32: Get rid of the SetDIBits driver entry point.

Alexandre Julliard julliard at winehq.org
Tue Jul 26 11:37:52 CDT 2011


Module: wine
Branch: master
Commit: 8a906250eb038bd8e06958547d1dae7cca68c8e8
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=8a906250eb038bd8e06958547d1dae7cca68c8e8

Author: Alexandre Julliard <julliard at winehq.org>
Date:   Mon Jul 25 19:47:03 2011 +0200

gdi32: Get rid of the SetDIBits driver entry point.

---

 dlls/gdi32/bitmap.c        |    7 -------
 dlls/gdi32/dib.c           |    4 ++--
 dlls/gdi32/dibdrv/dc.c     |    1 -
 dlls/gdi32/driver.c        |    1 -
 dlls/gdi32/enhmfdrv/init.c |    1 -
 dlls/gdi32/gdi_private.h   |    1 -
 dlls/gdi32/mfdrv/init.c    |    1 -
 dlls/wineps.drv/init.c     |    1 -
 dlls/winex11.drv/init.c    |    1 -
 include/wine/gdi_driver.h  |    3 +--
 10 files changed, 3 insertions(+), 18 deletions(-)

diff --git a/dlls/gdi32/bitmap.c b/dlls/gdi32/bitmap.c
index 0c745d9..e0df88d 100644
--- a/dlls/gdi32/bitmap.c
+++ b/dlls/gdi32/bitmap.c
@@ -79,13 +79,6 @@ LONG nulldrv_SetBitmapBits( HBITMAP bitmap, const void *bits, LONG size )
     return size;
 }
 
-INT nulldrv_SetDIBits( PHYSDEV dev, HBITMAP bitmap, UINT start, UINT lines,
-                       const void *bits, const BITMAPINFO *info, UINT coloruse )
-{
-    /* FIXME: transfer bits to bmp->bitmap.bmBits */
-    return 0;
-}
-
 /***********************************************************************
  *           BITMAP_GetWidthBytes
  *
diff --git a/dlls/gdi32/dibdrv/dc.c b/dlls/gdi32/dibdrv/dc.c
index 00dfddc..c78a111 100644
--- a/dlls/gdi32/dibdrv/dc.c
+++ b/dlls/gdi32/dibdrv/dc.c
@@ -522,7 +522,6 @@ const DC_FUNCTIONS dib_driver =
     dibdrv_SetDCBrushColor,             /* pSetDCBrushColor */
     dibdrv_SetDCPenColor,               /* pSetDCPenColor */
     dibdrv_SetDIBColorTable,            /* pSetDIBColorTable */
-    NULL,                               /* pSetDIBits */
     NULL,                               /* pSetDIBitsToDevice */
     dibdrv_SetDeviceClipping,           /* pSetDeviceClipping */
     NULL,                               /* pSetDeviceGammaRamp */
diff --git a/dlls/gdi32/driver.c b/dlls/gdi32/driver.c
index 56f9879..7ef76d8 100644
--- a/dlls/gdi32/driver.c
+++ b/dlls/gdi32/driver.c
@@ -762,7 +762,6 @@ const DC_FUNCTIONS null_driver =
     nulldrv_SetDCBrushColor,            /* pSetDCBrushColor */
     nulldrv_SetDCPenColor,              /* pSetDCPenColor */
     nulldrv_SetDIBColorTable,           /* pSetDIBColorTable */
-    nulldrv_SetDIBits,                  /* pSetDIBits */
     nulldrv_SetDIBitsToDevice,          /* pSetDIBitsToDevice */
     nulldrv_SetDeviceClipping,          /* pSetDeviceClipping */
     nulldrv_SetDeviceGammaRamp,         /* pSetDeviceGammaRamp */
diff --git a/dlls/gdi32/enhmfdrv/init.c b/dlls/gdi32/enhmfdrv/init.c
index 8d8e326..b4b9e6e 100644
--- a/dlls/gdi32/enhmfdrv/init.c
+++ b/dlls/gdi32/enhmfdrv/init.c
@@ -125,7 +125,6 @@ static const DC_FUNCTIONS EMFDRV_Funcs =
     EMFDRV_SetDCBrushColor,          /* pSetDCBrushColor*/
     EMFDRV_SetDCPenColor,            /* pSetDCPenColor*/
     NULL,                            /* pSetDIBColorTable */
-    NULL,                            /* pSetDIBits */
     EMFDRV_SetDIBitsToDevice,        /* pSetDIBitsToDevice */
     NULL,                            /* pSetDeviceClipping */
     NULL,                            /* pSetDeviceGammaRamp */
diff --git a/dlls/gdi32/gdi_private.h b/dlls/gdi32/gdi_private.h
index ea01d1b..0744a44 100644
--- a/dlls/gdi32/gdi_private.h
+++ b/dlls/gdi32/gdi_private.h
@@ -499,7 +499,6 @@ extern BOOL nulldrv_ScaleViewportExtEx( PHYSDEV dev, INT x_num, INT x_denom, INT
 extern BOOL nulldrv_ScaleWindowExtEx( PHYSDEV dev, INT x_num, INT x_denom, INT y_num, INT y_denom, SIZE *size ) DECLSPEC_HIDDEN;
 extern BOOL nulldrv_SelectClipPath( PHYSDEV dev, INT mode ) DECLSPEC_HIDDEN;
 extern LONG nulldrv_SetBitmapBits( HBITMAP bitmap, const void *bits, LONG size ) DECLSPEC_HIDDEN;
-extern INT  nulldrv_SetDIBits( PHYSDEV dev, HBITMAP bitmap, UINT start, UINT lines, const void *bits, const BITMAPINFO *info, UINT coloruse ) DECLSPEC_HIDDEN;
 extern INT  nulldrv_SetMapMode( PHYSDEV dev, INT mode ) DECLSPEC_HIDDEN;
 extern BOOL nulldrv_SetViewportExtEx( PHYSDEV dev, INT cx, INT cy, SIZE *size ) DECLSPEC_HIDDEN;
 extern BOOL nulldrv_SetViewportOrgEx( PHYSDEV dev, INT x, INT y, POINT *pt ) DECLSPEC_HIDDEN;
diff --git a/dlls/gdi32/mfdrv/init.c b/dlls/gdi32/mfdrv/init.c
index 65487fd..1474014 100644
--- a/dlls/gdi32/mfdrv/init.c
+++ b/dlls/gdi32/mfdrv/init.c
@@ -169,7 +169,6 @@ static const DC_FUNCTIONS MFDRV_Funcs =
     MFDRV_SetDCBrushColor,           /* pSetDCBrushColor*/
     MFDRV_SetDCPenColor,             /* pSetDCPenColor*/
     NULL,                            /* pSetDIBColorTable */
-    NULL,                            /* pSetDIBits */
     MFDRV_SetDIBitsToDevice,         /* pSetDIBitsToDevice */
     NULL,                            /* pSetDeviceClipping */
     NULL,                            /* pSetDeviceGammaRamp */
diff --git a/dlls/wineps.drv/init.c b/dlls/wineps.drv/init.c
index e9b0a04..f038a66 100644
--- a/dlls/wineps.drv/init.c
+++ b/dlls/wineps.drv/init.c
@@ -891,7 +891,6 @@ static const struct gdi_dc_funcs psdrv_funcs =
     PSDRV_SetDCBrushColor,              /* pSetDCBrushColor */
     PSDRV_SetDCPenColor,                /* pSetDCPenColor */
     NULL,                               /* pSetDIBColorTable */
-    NULL,                               /* pSetDIBits */
     NULL,                               /* pSetDIBitsToDevice */
     NULL,                               /* pSetDeviceClipping */
     NULL,                               /* pSetDeviceGammaRamp */
diff --git a/dlls/winex11.drv/init.c b/dlls/winex11.drv/init.c
index b3449a8..26a7973 100644
--- a/dlls/winex11.drv/init.c
+++ b/dlls/winex11.drv/init.c
@@ -534,7 +534,6 @@ static const struct gdi_dc_funcs x11drv_funcs =
     X11DRV_SetDCBrushColor,             /* pSetDCBrushColor */
     X11DRV_SetDCPenColor,               /* pSetDCPenColor */
     X11DRV_SetDIBColorTable,            /* pSetDIBColorTable */
-    NULL,                               /* pSetDIBits */
     X11DRV_SetDIBitsToDevice,           /* pSetDIBitsToDevice */
     X11DRV_SetDeviceClipping,           /* pSetDeviceClipping */
     X11DRV_SetDeviceGammaRamp,          /* pSetDeviceGammaRamp */
diff --git a/include/wine/gdi_driver.h b/include/wine/gdi_driver.h
index 87c12d7..5a251a1 100644
--- a/include/wine/gdi_driver.h
+++ b/include/wine/gdi_driver.h
@@ -143,7 +143,6 @@ struct gdi_dc_funcs
     COLORREF (*pSetDCBrushColor)(PHYSDEV, COLORREF);
     COLORREF (*pSetDCPenColor)(PHYSDEV, COLORREF);
     UINT     (*pSetDIBColorTable)(PHYSDEV,UINT,UINT,const RGBQUAD*);
-    INT      (*pSetDIBits)(PHYSDEV,HBITMAP,UINT,UINT,LPCVOID,const BITMAPINFO*,UINT);
     INT      (*pSetDIBitsToDevice)(PHYSDEV,INT,INT,DWORD,DWORD,INT,INT,UINT,UINT,LPCVOID,const BITMAPINFO*,UINT);
     VOID     (*pSetDeviceClipping)(PHYSDEV,HRGN,HRGN);
     BOOL     (*pSetDeviceGammaRamp)(PHYSDEV,LPVOID);
@@ -191,7 +190,7 @@ struct gdi_dc_funcs
 };
 
 /* increment this when you change the DC function table */
-#define WINE_GDI_DRIVER_VERSION 7
+#define WINE_GDI_DRIVER_VERSION 8
 
 static inline PHYSDEV get_physdev_entry_point( PHYSDEV dev, size_t offset )
 {




More information about the wine-cvs mailing list
diff --git a/dlls/gdi32/dib.c b/dlls/gdi32/dib.c
index f7b9037..4f5b970 100644
--- a/dlls/gdi32/dib.c
+++ b/dlls/gdi32/dib.c
@@ -397,8 +397,8 @@ INT nulldrv_StretchDIBits( PHYSDEV dev, INT xDst, INT yDst, INT widthDst, INT he
     HBITMAP hBitmap;
     HDC hdcMem;
 
-    /* make sure we have a real implementation for StretchBlt and SetDIBits */
-    if (GET_DC_PHYSDEV( dc, pStretchBlt ) == dev || GET_DC_PHYSDEV( dc, pSetDIBits ) == dev)
+    /* make sure we have a real implementation for StretchBlt and PutImage */
+    if (GET_DC_PHYSDEV( dc, pStretchBlt ) == dev || GET_DC_PHYSDEV( dc, pPutImage ) == dev)
         return 0;
 
     if (DIB_GetBitmapInfo( &info->bmiHeader, &width, &height, &planes, &bpp, &compr, &size ) == -1)